==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/multipath/classes.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import definitions
import logging
from execute import ExternalCommand
from udev_rules import UdevRules
from multipath_conf import MultiPathConf
from kernel_modules import MultiPathKernelModules
from service import GenericServiceManager
from hostattachment.exceptions import HostAttachmentError

class MultipathConfiguration(object):
    def __init__(self, backup_path):
#        self.log_used_classes()
        self.backup_path = backup_path
        self.udev_rules = UdevRules()
        self.kernel_modules = MultiPathKernelModules()
        self.multipathd = GenericServiceManager('multipath')

    def configure_multipath(self):
        self.configure()

    def get_configuration_task_list(self):
        tasks = []
        multipath_conf = MultiPathConf(self.backup_path)

        if not self.udev_rules.is_configured():
            tasks.append("Need to add udev rules")
        if not multipath_conf.is_configured():
            tasks.append("Need to configure multipath.conf")
        if not self.kernel_modules.is_configured():
            tasks.append("Need to load kernel modules")
        if not self.multipathd.is_configured():
            tasks.append("Need to configure multipathd service")
        return tasks

    def is_multipath_configured(self):
        if self.get_configuration_task_list():
            return False
        else:
            return True

    def log_used_classes(self):
        self.logger.log_a_class(UdevRules)
        self.logger.log_a_class(MultiPathConf)
        self.logger.log_a_class(MultiPathKernelModules)

    def configure(self):
        multipath_conf = MultiPathConf(self.backup_path)
        self.udev_rules.configure()
        multipath_conf.configure()
        self.kernel_modules.configure()
        self.multipathd.configure()

    def update_maps(self):
        multipath_command = ExternalCommand('multipath -F')
        multipath_command.execute()
        multipath_command = ExternalCommand('multipath')
        multipath_command.execute()

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/multipath/classes.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import definitions
import logging
from execute import ExternalCommand
from udev_rules import UdevRules
from multipath_conf import MultiPathConf
from kernel_modules import MultiPathKernelModules
from service import GenericServiceManager
from hostattachment.exceptions import HostAttachmentError

class MultipathConfiguration(object):
    def __init__(self, backup_path):
#        self.log_used_classes()
        self.backup_path = backup_path
        self.udev_rules = UdevRules(self.backup_path)
        self.kernel_modules = MultiPathKernelModules()
        self.multipathd = GenericServiceManager('multipath')

    def configure_multipath(self):
        self.configure()

    def get_configuration_task_list(self):
        tasks = []
        multipath_conf = MultiPathConf(self.backup_path)

        if not self.udev_rules.is_configured():
            tasks.append("Need to add udev rules")
        if not multipath_conf.is_configured():
            tasks.append("Need to configure multipath.conf")
        if not self.kernel_modules.is_configured():
            tasks.append("Need to load kernel modules")
        if not self.multipathd.is_configured():
            tasks.append("Need to configure multipathd service")
        return tasks

    def is_multipath_configured(self):
        if self.get_configuration_task_list():
            return False
        else:
            return True

    def log_used_classes(self):
        self.logger.log_a_class(UdevRules)
        self.logger.log_a_class(MultiPathConf)
        self.logger.log_a_class(MultiPathKernelModules)

    def configure(self):
        multipath_conf = MultiPathConf(self.backup_path)
        self.udev_rules.configure()
        multipath_conf.configure()
        self.kernel_modules.configure()
        self.multipathd.configure()

    def update_maps(self):
        multipath_command = ExternalCommand('multipath -F')
        multipath_command.execute()
        multipath_command = ExternalCommand('multipath')
        multipath_command.execute()
